'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
// tslint:disable-next-line variable-name
const HttpsProxyAgent = require('https-proxy-agent');
const requestToFetchOptions = (reqOpts) => {
    const options = Object.assign({}, reqOpts.method && { method: reqOpts.method }, reqOpts.timeout && { timeout: reqOpts.timeout }, reqOpts.gzip && { compress: reqOpts.gzip });
    if (typeof reqOpts.json === 'object') {
        // Add Content-type: application/json header
        if (!reqOpts.headers) {
            reqOpts.headers = {};
        }
        reqOpts.headers['Content-Type'] = 'application/json';
        // Set body to JSON representation of value
        options.body = JSON.stringify(reqOpts.json);
    }
    else {
        options.body = JSON.stringify(reqOpts.body);
    }
    options.headers = reqOpts.headers;
    let uri = reqOpts.uri;
    if (reqOpts.useQuerystring === true) {
        const qs = require('querystring');
        const params = qs.stringify(reqOpts.qs);
        uri = uri + '?' + params;
    }
    if (reqOpts.proxy || process.env.HTTP_PROXY || process.env.HTTPS_PROXY) {
        const proxy = (process.env.HTTP_PROXY || process.env.HTTPS_PROXY);
        options.agent = new HttpsProxyAgent(proxy);
    }
    return [uri, options];
};
const fetchToRequestResponse = (res) => {
    const response = {
        statusCode: res.status,
        statusMessage: res.statusText,
    };
    return response;
};
const teenyRequest = ((reqOpts, callback) => {
    const [uri, options] = requestToFetchOptions(reqOpts);
    node_fetch_1.default(uri, options)
        .then((res) => {
        const header = res.headers.get('content-type');
        if (header === 'application/json' ||
            header === 'application/json; charset=utf-8') {
            const response = fetchToRequestResponse(res);
            res.json()
                .then(json => {
                response.body = json;
                callback(null, response, json);
            })
                .catch((err) => {
                callback(err);
            });
            return;
        }
        res.text()
            .then(text => {
            const response = fetchToRequestResponse(res);
            response.body = text;
            callback(null, response, text);
        })
            .catch(err => {
            callback(err);
        });
    })
        .catch((err) => {
        callback(err);
    });
});
exports.teenyRequest = teenyRequest;
teenyRequest.defaults = (defaults) => {
    return (reqOpts, callback) => {
        teenyRequest(Object.assign({}, defaults, reqOpts), callback);
    };
};
//# sourceMappingURL=index.js.map